/***************************************************************************
                          guitext.cpp  -  description
                             -------------------
    begin                : Tue Jun 15 2004
    copyright            : (C) 2004 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "guitext.hpp"

GUIText::GUIText( int x, int y) : puText ( x, y )
{
}
void GUIText::setText(const char *text)
{
    strncpy(labeltext,text,255);
    setLabel(labeltext);
}

GUIText::~GUIText(){
}
